Learn R Programming

geoFourierFDA (version 0.1.0)

coef_fourier: This function computes minimum square estimates for Fourier coefficients.

Description

This function computes minimum square estimates for Fourier coefficients.

Usage

coef_fourier(f, m)

Arguments

f

A time series to be smoothed.

m

Order of the Fourier polynomial. Default value is computed using the Sturge's rule.

Value

A vector with the fourier coefficients.

Examples

Run this code
# NOT RUN {
data(canada)

coef_fourier(canada$ThePas_ts)
# }

Run the code above in your browser using DataLab