Learn R Programming

geoFourierFDA (version 0.1.0)

geo_model: EStimates the parameters of the exponential model.

Description

geo_model finds the maximum likelihood estimate for the parameters in the geostatistical exponential model.

Usage

geo_model(v_data, m_coord)

Arguments

v_data

a numeric vector with the data

m_coord

a matrix with two column. The first column must be the latitude and the second column must be the longitude.

Value

a list with components

mean

mean of the process

phi

range of exponential model

sigmasq

total sill of exponential model

convergence

convergence as specified in the function nlminb

Examples

Run this code
# NOT RUN {
data(canada)
v_data <- canada$m_data[1, ]
geo_model(v_data, canada$m_coord)
# }

Run the code above in your browser using DataLab