powered by
geo_model finds the maximum likelihood estimate for the parameters in the geostatistical exponential model.
geo_model
geo_model(v_data, m_coord)
a numeric vector with the data
a matrix with two column. The first column must be the latitude and the second column must be the longitude.
a list with components
mean
mean of the process
phi
range of exponential model
sigmasq
total sill of exponential model
convergence
convergence as specified in the function nlminb
nlminb
# NOT RUN { data(canada) v_data <- canada$m_data[1, ] geo_model(v_data, canada$m_coord) # }
Run the code above in your browser using DataLab